core.match_filter.matched_filter
--------------------------------

.. currentmodule:: eqcorrscan.core.match_filter.matched_filter
.. automodule:: eqcorrscan.core.match_filter.matched_filter

    .. comment to end block

    Functions
    ---------
    .. autosummary::
       :toctree: autogen
       :nosignatures:

       match_filter

    .. comment to end block